.. _dev-kit-API-cmd:

microspeclib.simple module (dev-kit API commands)
=================================================

.. automodule:: microspeclib.simple
   :members:
   :undoc-members:
   :inherited-members:
   :exclude-members: consume, flush, pushback, read, receiveCommand, receiveReply, sendAndReceive, sendCommand, sendReply, write
